==> saga-1.0.5.tgz: package/lib/tests/actions.test.js <==
'use strict';

var _bootstrapStyled = require('bootstrap-styled');

var _actions = require('../actions');

var _constants = require('../constants');

describe('bootstrap-styled-saga actions', function () {
  var theme = void 0;
  beforeAll(function () {
    theme = (0, _bootstrapStyled.makeTheme)({
      '$brand-primary': 'red'
    });
  });

  describe('changeThemeRequest', function () {
    it('should dispatch changeThemeRequest', function () {
      expect((0, _actions.changeThemeRequest)('someid')).toEqual({
        type: _constants.CHANGE_THEME_REQUEST,
        name: 'someid'
      });
    });
  });

  describe('changeThemeFailure', function () {
    it('should dispatch changeThemeFailure', function () {
      var error = new Error('failure');
      expect((0, _actions.changeThemeFailure)(theme._name, error)).toEqual({ // eslint-disable-line no-underscore-dangle
        type: _constants.CHANGE_THEME_FAILURE,
        error: error,
        current: theme._name // eslint-disable-line no-underscore-dangle
      });
    });
  });

  describe('deleteAsyncThemes', function () {
    it('should dispatch deleteAsyncThemes', function () {
      expect((0, _actions.deleteAsyncThemes)()).toEqual({
        type: _constants.DELETE_ASYNC_THEMES
      });
    });
  });

  describe('storeAsyncTheme', function () {
    it('should dispatch storeAsyncTheme', function () {
      expect((0, _actions.storeAsyncTheme)(theme)).toEqual({
        type: _constants.STORE_ASYNC_THEME,
        theme: theme
      });
    });
  });
});

==> saga-1.1.1.tgz: package/lib/tests/actions.test.js <==
"use strict";

var _bootstrapStyled = require("bootstrap-styled");

var _actions = require("../actions");

var _constants = require("../constants");

describe('bootstrap-styled-saga actions', function () {
  var theme;
  beforeAll(function () {
    theme = (0, _bootstrapStyled.makeTheme)({
      '$brand-primary': 'red'
    });
  });
  describe('changeThemeRequest', function () {
    it('should dispatch changeThemeRequest', function () {
      expect((0, _actions.changeThemeRequest)('someid')).toEqual({
        type: _constants.CHANGE_THEME_REQUEST,
        name: 'someid'
      });
    });
  });
  describe('changeThemeFailure', function () {
    it('should dispatch changeThemeFailure', function () {
      var error = new Error('failure');
      expect((0, _actions.changeThemeFailure)(theme._name, error)).toEqual({
        // eslint-disable-line no-underscore-dangle
        type: _constants.CHANGE_THEME_FAILURE,
        error: error,
        current: theme._name // eslint-disable-line no-underscore-dangle

      });
    });
  });
  describe('deleteAsyncThemes', function () {
    it('should dispatch deleteAsyncThemes', function () {
      expect((0, _actions.deleteAsyncThemes)()).toEqual({
        type: _constants.DELETE_ASYNC_THEMES
      });
    });
  });
  describe('storeAsyncTheme', function () {
    it('should dispatch storeAsyncTheme', function () {
      expect((0, _actions.storeAsyncTheme)(theme)).toEqual({
        type: _constants.STORE_ASYNC_THEME,
        theme: theme
      });
    });
  });
});
